@@ -19,8 +19,6 @@
 int main(int argc, char **argv)
 {
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
