@@ -42,8 +42,6 @@ int main(int argc, char *argv[])
 {
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kdeconnect-sms");
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
